@@ -119,7 +119,7 @@ int start_dhcpv6_client(struct debconfclient *client, const struct netcfg_interf
 			arguments[i++] = "-cf";
 			arguments[i++] = DHCLIENT6_FILE;
 			arguments[i++] = "-sf";
-			arguments[i++] = "/lib/netcfg/print-dhcpv6-info";
+			arguments[i++] = "/usr/lib/netcfg/print-dhcpv6-info";
 			arguments[i++] = interface->name;
 			arguments[i] = NULL;
 			execvp("dhclient", (char **)arguments);
@@ -152,7 +152,7 @@ int start_dhcpv6_client(struct debconfclient *client, const struct netcfg_interf
 				fprintf(dc, "\tsend ia-na 0;\n");
 			fprintf(dc, "\trequest domain-name-servers;\n");
 			fprintf(dc, "\trequest domain-name;\n");
-			fprintf(dc, "\tscript \"/lib/netcfg/print-dhcp6c-info\";\n");
+			fprintf(dc, "\tscript \"/usr/lib/netcfg/print-dhcp6c-info\";\n");
 			fprintf(dc, "};\n");
 			if (!interface->v6_stateless_config) {
 				fprintf(dc, "id-assoc na 0 {\n");
